import { HazelReader } from "@skeldjs/util";
import { BaseRpcMessage } from "@skeldjs/protocol";
import { SpawnType, SystemType } from "@skeldjs/constant";
import { ShipStatusData, InnerShipStatus } from "./InnerShipStatus";
import { HudOverrideSystem, LifeSuppSystem, MedScanSystem, SecurityCameraSystem, AutoDoorsSystem, SabotageSystem, SwitchSystem, ReactorSystem } from "../systems";
import { Hostable } from "../Hostable";
import { NetworkableConstructor } from "../Heritable";
import { Networkable } from "../Networkable";
/**
 * Represents a room object for the The Skeld map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
export declare class SkeldShipStatus<RoomType extends Hostable = Hostable> extends InnerShipStatus<RoomType> {
    static roomDoors: {
        1: number[];
        2: number[];
        4: number[];
        7: number[];
        10: number[];
        11: number[];
        13: number[];
    };
    systems: {
        [SystemType.Reactor]: ReactorSystem<RoomType>;
        [SystemType.Electrical]: SwitchSystem<RoomType>;
        [SystemType.O2]: LifeSuppSystem<RoomType>;
        [SystemType.MedBay]: MedScanSystem<RoomType>;
        [SystemType.Security]: SecurityCameraSystem<RoomType>;
        [SystemType.Communications]: HudOverrideSystem<RoomType>;
        [SystemType.Doors]: AutoDoorsSystem<RoomType>;
        [SystemType.Sabotage]: SabotageSystem<RoomType>;
    };
    constructor(room: RoomType, spawnType: SpawnType, netid: number, ownerid: number, flags: number, data?: HazelReader | ShipStatusData);
    getComponent<T extends Networkable>(component: NetworkableConstructor<T>): T | undefined;
    HandleRpc(rpc: BaseRpcMessage): Promise<void>;
    private _handleCloseDoorsOfType;
    Setup(): void;
}
